"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
// Imports: Dependencies
const react_1 = __importStar(require("react"));
const react_native_1 = require("react-native");
const datetimepicker_1 = __importDefault(require("@react-native-community/datetimepicker"));
const react_native_modal_1 = __importDefault(require("react-native-modal"));
const moment_1 = __importDefault(require("moment"));
// Screen Dimensions
const { height, width } = react_native_1.Dimensions.get('window');
// Component: Time Picker
const TimePicker = (props) => {
    // React Hooks: State
    const [modalVisible, toggle] = react_1.useState(false);
    const [androidModalVisible, toggleAndroid] = react_1.useState(false);
    const [date, setDate] = react_1.useState(new Date());
    // Toggle Modal
    const toggleModal = () => {
        try {
            // Check Platform (Android)
            if (react_native_1.Platform.OS === 'android') {
                // React Hook: Toggle Android
                toggleAndroid((androidModalVisible) => !androidModalVisible);
            }
            // Check Platform (iOS)
            if (react_native_1.Platform.OS === 'ios') {
                // React Hook: Toggle Modal
                toggle((modalVisible) => !modalVisible);
            }
        }
        catch (error) {
            console.log(error);
        }
    };
    // Select Date
    const selectDate = (event, date) => {
        try {
            // Check Platform: Android
            if (react_native_1.Platform.OS === 'android' && date !== undefined) {
                // Event Type: Set Date
                if (event.type === 'set') {
                    // React Hook: Toggle Android 
                    toggleAndroid(false);
                    // React Hook: Set From Date
                    setDate(date);
                    // React Props: onChange
                    props.onChange(date);
                }
                // Event Type: Dismissed
                if (event.type === 'dismissed') {
                    // React Hook: Toggle Android
                    toggleAndroid(false);
                }
            }
            // Check Platform: Android
            if (react_native_1.Platform.OS === 'ios') {
                setDate(date);
                // React Props: onChange
                props.onChange(date);
            }
        }
        catch (error) {
            console.log(error);
        }
    };
    // Render iOS Picker
    const renderIOSPicker = () => {
        try {
            return (react_1.default.createElement(datetimepicker_1.default, { mode: "time", value: date, onChange: (event, date) => selectDate(event, date) }));
        }
        catch (error) {
            console.log(error);
        }
    };
    // Render Android Picker
    const renderAndroidPicker = () => {
        try {
            if (androidModalVisible === true) {
                return (react_1.default.createElement(datetimepicker_1.default, { mode: "time", display: props.mode, value: date, onChange: (event, date) => selectDate(event, date) }));
            }
        }
        catch (error) {
            console.log(error);
        }
    };
    return (react_1.default.createElement(react_native_1.View, { style: styles.container },
        react_1.default.createElement(react_native_1.View, { style: styles.inputTitleContainer },
            react_1.default.createElement(react_native_1.Text, { style: styles.inputTitle }, props.title)),
        react_1.default.createElement(react_native_1.TouchableOpacity, { onPress: () => toggleModal(), style: styles.fieldTextContainer },
            react_1.default.createElement(react_native_1.Text, { style: styles.fieldText, numberOfLines: 1 }, date ? moment_1.default(date).format('h:mm a') : 'Select')),
        react_1.default.createElement(react_native_1.View, null, androidModalVisible === true ? renderAndroidPicker() : null),
        react_1.default.createElement(react_native_modal_1.default, { isVisible: modalVisible, style: styles.modal },
            react_1.default.createElement(react_native_1.View, { style: styles.modalContainer },
                react_1.default.createElement(react_native_1.View, { style: styles.pickerHeaderContainer },
                    react_1.default.createElement(react_native_1.TouchableOpacity, { onPress: () => toggleModal() },
                        react_1.default.createElement(react_native_1.Text, { style: styles.doneText }, "Done"))),
                react_1.default.createElement(react_native_1.View, { style: styles.pickerContainer }, renderIOSPicker())))));
};
// Styles
const styles = react_native_1.StyleSheet.create({
    container: {
        display: 'flex',
        width: width - 32,
        marginLeft: 16,
        marginRight: 16,
        justifyContent: 'center',
    },
    modal: {
        margin: 0,
    },
    modalContainer: {
        height: '100%',
        alignItems: 'center',
        justifyContent: 'flex-end',
    },
    pickerHeaderContainer: {
        display: 'flex',
        flexDirection: 'row',
        justifyContent: 'flex-end',
        alignItems: 'center',
        height: 40,
        width: width,
        backgroundColor: '#FAFAF8',
        borderColor: '#7D7D7D',
        borderBottomWidth: react_native_1.StyleSheet.hairlineWidth,
    },
    pickerContainer: {
        height: 220,
        width: width,
        // backgroundColor: '#CFD3D9',
        backgroundColor: 'white',
    },
    doneText: {
        fontFamily: 'System',
        color: '#007AFF',
        fontWeight: '600',
        fontSize: 17,
        marginRight: 16,
    },
    stateContainer: {
        alignItems: 'center',
        width: 75,
        borderColor: '#7D7D7D',
        borderBottomWidth: react_native_1.StyleSheet.hairlineWidth,
    },
    inputTitleContainer: {
        width: 75,
        marginBottom: 4,
    },
    inputTitle: {
        color: '#7D7D7D',
        borderColor: '#7D7D7D',
        fontSize: 10,
        fontWeight: '600',
        textTransform: 'uppercase',
    },
    fieldTextContainer: {
        height: 40,
        display: 'flex',
        flexDirection: 'row',
        justifyContent: 'space-between',
        alignItems: 'center',
        marginBottom: 4,
        borderColor: '#7D7D7D',
        borderBottomWidth: react_native_1.StyleSheet.hairlineWidth,
    },
    fieldText: {
        width: width - 32 - 20,
        fontFamily: 'System',
        fontSize: 17,
        fontWeight: '400',
        color: '#000000',
        alignSelf: 'center',
    },
    arrowForward: {
        color: 'black',
        opacity: .3,
        marginRight: 7,
    },
});
// Exports
exports.default = TimePicker;
